# {{name}}


## Description
{{description}}

## Use 
To install the required dependencies:
```shell
yarn 
```
To build for development:
```shell
yarn build:dev
```
To build for production:
```shell
yarn build:prod
```

To test:
```shell
yarn test
```


